pqp.refutation package
======================

Submodules
----------

pqp.refutation.result module
----------------------------

.. automodule:: pqp.refutation.result
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pqp.refutation
   :members:
   :undoc-members:
   :show-inheritance:
